import { Indentify, isParseable, onParseToJsonWarning } from './Utils/index.js';

import JSONDOMtoJSON from './JSON/JSONDOMtoJSON.js';
import DOMtoJSON from './JSON/DOMtoJSON.js';
import JSONtoJSONDOM from './JSONDOM/JSONtoJSONDOM.js';
import DOMtoJSONDOM from './JSONDOM/DOMtoJSONDOM.js'
import JSONtoDOM from './DOM/JSONtoDOM.js';

class Parse {
    // -- Fix Chaining
    constructor({ structure, warning = true }) {
        this.value = Array.isArray(structure) ? structure[0] : structure;
        const indentified = Indentify(this.value);
        this.type = isParseable(indentified) && indentified.type;
        this.typeCode = indentified.code;
        this.warning = warning;
    };
    JSON() {
        if (this.typeCode === 1) {
            this.value = JSONDOMtoJSON({ structure: [this.value] });
        } else if (this.typeCode === 2) {
            this.value = DOMtoJSON({ structure: this.value });
        };
        if (this.warning) {
            onParseToJsonWarning();
        };
        return this;
    };
    JSONDOM() {
        if (this.typeCode === 1) {
            this.value = JSONtoJSONDOM({ structure: this.value });
        } else if (this.typeCode === 2) {
            this.value = DOMtoJSONDOM({ structure: this.value });
        };
        return this;
    };
    DOM() {
        this.value = JSONtoDOM({ structure: [this.value] });
        return this;
    };
};

export { JSONDOM, Parse };
